@@ -171,7 +171,7 @@ typedef struct gnutls_hash_entry gnutls_hash_entry;
 static const gnutls_hash_entry hash_algorithms[] = {
     {"SHA", HASH_OID_SHA1, GNUTLS_MAC_SHA1},
     {"MD5", HASH_OID_MD5, GNUTLS_MAC_MD5},
-    {"MD2", HASH_OID_MD2, 0/*GNUTLS_MAC_MD2*/},
+    {"MD2", HASH_OID_MD2, GNUTLS_MAC_MD2},
     {"RIPEMD160", HASH_OID_RMD160, GNUTLS_MAC_RMD160},
     {"NULL", NULL, GNUTLS_MAC_NULL},
     {0, 0, 0}
@@ -1429,7 +1429,7 @@ static const gnutls_sign_entry sign_algorithms[] = {
     {"RSA-RMD160", SIG_RSA_RMD160_OID, GNUTLS_SIGN_RSA_RMD160, GNUTLS_PK_RSA, GNUTLS_MAC_RMD160},
     {"DSA-SHA", SIG_DSA_SHA1_OID, GNUTLS_SIGN_DSA_SHA1, GNUTLS_PK_DSA, GNUTLS_MAC_SHA1},
     {"RSA-MD5", SIG_RSA_MD5_OID, GNUTLS_SIGN_RSA_MD5, GNUTLS_PK_RSA, GNUTLS_MAC_MD5},
-    {"RSA-MD2", SIG_RSA_MD2_OID, GNUTLS_SIGN_RSA_MD2, GNUTLS_PK_RSA, 0/*GNUTLS_MAC_MD2*/},
+    {"RSA-MD2", SIG_RSA_MD2_OID, GNUTLS_SIGN_RSA_MD2, GNUTLS_PK_RSA, GNUTLS_MAC_MD2},
     {"GOST R 34.10-2001", SIG_GOST_R3410_2001_OID, 0, 0, 0},
     {"GOST R 34.10-94", SIG_GOST_R3410_94_OID, 0, 0, 0},
     {0, 0, 0, 0, 0}
