@@ -1,5 +1,6 @@
 /*
  *      Copyright (C) 2002  Fabio Fiorina
+ *      Copyright (C) 2004  Simon Josefsson
  *
  * This file is part of LIBASN1.
  *
@@ -15,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,  USA
  */
 
 
@@ -246,7 +247,7 @@ _asn1_objectid_der(unsigned char *str,unsigned char *der,int *der_len)
 
   max_len=*der_len;
 
-  temp=(char *) _asn1_alloca(strlen(str)+2);
+  temp= (char *) _asn1_alloca(strlen(str)+2);
   if(temp==NULL) return ASN1_MEM_ALLOC_ERROR;
 
   strcpy(temp, str);
@@ -716,33 +717,37 @@ _asn1_ordering_set_of(unsigned char *der,node_asn *node)
 /**
   * asn1_der_coding - Creates the DER encoding for the NAME structure
   * @element: pointer to an ASN1 element
-  * @name: the name of the structure you want to encode (it must be inside *POINTER).
-  * @ider: vector that will contain the DER encoding. DER must be a pointer to memory cells already allocated.
-  * @len: number of bytes of *der: der[0]..der[len-1], Initialy holds the sizeof of der vector.
-  * @errorDescription : return the error description or an empty string if success.
-  * Description:
+  * @name: the name of the structure you want to encode (it must be
+  *   inside *POINTER).
+  * @ider: vector that will contain the DER encoding. DER must be a
+  *   pointer to memory cells already allocated.
+  * @len: number of bytes of *@ider: @ider[0]..@ider[len-1], Initialy
+  *   holds the sizeof of der vector.
+  * @errorDescription : return the error description or an empty
+  *   string if success.
+  *
+  * Creates the DER encoding for the NAME structure (inside *POINTER
+  * structure).
   *
-  * Creates the DER encoding for the NAME structure (inside *POINTER structure).
-  * 
   * Returns:
   *
-  *   ASN1_SUCCESS\: DER encoding OK
+  *   ASN1_SUCCESS: DER encoding OK.
   *
-  *   ASN1_ELEMENT_NOT_FOUND\: NAME is not a valid element.
+  *   ASN1_ELEMENT_NOT_FOUND: NAME is not a valid element.
   *
-  *   ASN1_VALUE_NOT_FOUND\: there is an element without a value.
+  *   ASN1_VALUE_NOT_FOUND: There is an element without a value.
   *
-  *   ASN1_MEM_ERROR\: der vector isn't big enough. Also in this case LEN
-  *   will contain the length needed.
+  *   ASN1_MEM_ERROR: @ider vector isn't big enough. Also in this case
+  *     LEN will contain the length needed.
   *
   **/
-asn1_retCode 
+asn1_retCode
 asn1_der_coding(ASN1_TYPE element,const char *name,void *ider,int *len,
                 char *ErrorDescription)
 {
   node_asn *node,*p,*p2;
   char temp[SIZEOF_UNSIGNED_LONG_INT*3+1];
-  int counter,counter_old,len2,len3,move,max_len,max_len_old;
+  int counter,counter_old,len2,len3,tlen,move,max_len,max_len_old;
   asn1_retCode ris;
   unsigned char* der = ider;
 
@@ -875,7 +880,9 @@ asn1_der_coding(ASN1_TYPE element,const char *name,void *ider,int *len,
     case TYPE_SEQUENCE: case TYPE_SET: 
       if(move!=UP){
 	_asn1_ltostr(counter,temp);
-	_asn1_set_value(p,temp,strlen(temp)+1);
+	tlen = strlen(temp);
+	if (tlen > 0)
+	   _asn1_set_value(p,temp,tlen+1);
 	if(p->down==NULL){
 	  move=UP;
 	  continue;
@@ -910,7 +917,10 @@ asn1_der_coding(ASN1_TYPE element,const char *name,void *ider,int *len,
     case TYPE_SEQUENCE_OF: case TYPE_SET_OF:
       if(move!=UP){
 	_asn1_ltostr(counter,temp);
-	_asn1_set_value(p,temp,strlen(temp)+1);
+	tlen = strlen(temp);
+	
+	if (tlen > 0)
+	   _asn1_set_value(p,temp,tlen+1);
 	p=p->down;
 	while((type_field(p->type)==TYPE_TAG) || (type_field(p->type)==TYPE_SIZE)) p=p->right;
 	if(p->right){
