@@ -2240,6 +2240,13 @@ static void print_verification_res(gnutls_x509_crt crt,
 	comma = 1;
     }
 
+    if (output & GNUTLS_CERT_INSECURE_ALGORITHM) {
+      if (comma)
+	fprintf(outfile, ", ");
+      fprintf(outfile, "Insecure algorithm");
+      comma = 1;
+    }
+
     /* Check expiration dates.
      */
 
@@ -2343,6 +2350,13 @@ void verify_crl(void)
 	comma = 1;
     }
 
+    if (output & GNUTLS_CERT_INSECURE_ALGORITHM) {
+      if (comma)
+	fprintf(outfile, ", ");
+      fprintf(outfile, "Insecure algorithm");
+      comma = 1;
+    }
+
     /* Check expiration dates.
      */
 
@@ -2500,7 +2514,7 @@ void generate_pkcs12(void)
 	key_id.data = _key_id;
 	key_id.size = size;
 
-	result = gnutls_pkcs12_bag_set_key_id(kbag, result, &key_id);
+	result = gnutls_pkcs12_bag_set_key_id(kbag, index, &key_id);
 	if (result < 0) {
 	    fprintf(stderr, "bag_set_key_id: %s\n",
 		    gnutls_strerror(result));
